# This code has been merged into the original repository and the original package is now updated.

Please use the original repository
at [django-background-tasks](https://github.com/django-background-tasks/django-background-tasks) and the original
package at [django-background-tasks](https://pypi.org/project/django-background-tasks/) going forward.
